###################
## ALLEGRO - CASA training day March 3 2017
## Selfcalibration script for IRAS16293 BAND 4 ALMA - SV dataset
## L. T. Maud
###################

import re

# check the casa version - use the one you calibrated with
if re.search('^5.4', casadef.casa_version) == None:
 sys.exit('ERROR: PLEASE USE THE SAME VERSION OF CASA THAT YOU USED FOR GENERATING THE SCRIPT: 5.4')


inputvisname    = 'uid___A002_X867766_Xa7.ms.split.cal'  # or your MS filename
visname         ='IRAS16293.ms.split.cal'  # this will be the split out file of your source only

cell            ='0.15arcsec'  # set this for the imaging - 5 to 8 time less than beam
imagesize       =256      # enough to image at least ALL primary beam
souname         ='IRAS16293'  # source name
#
# Select the SPW and CHANNELS that comprise the continuum
# e.g. 4 SPW below
# select either side for 0 and 3
# select all of SPW 1 and 2
#
# this was manually checked in plotms with various commands
# this should be done very carefully
#
spwcont =  '0:0~210;320~400;500~860;980~1020;1240~1350;1550~1640;'
spwcont += '1780~2220;2340~2360;2460~2700;2840~3200;3400~3450;3750~3839,'
spwcont += '1:0~9;130~220;290~315;375~425;660~785;925~945;970~1020;1115~1200;'
spwcont += '1570~1640;2100~2140;2680~2770;2980~3020,'
spwcont += '2:0~470;820~1020;1420~1460;1680~1760;1980~2200;'
spwcont += '2430~2660;2960~3400;3690~3839,3:70~140;300~350;420~460;
spwcont += '960~1100;1350~1390;1520~1580;2010~2090;2185~2350;2865~2890;'
spwcont += '3000~3060;3250~3625'
#
# dont use the flagging data command - select the continuum you want
# easier with book keeping 
#
thesteps    = []
step_title  = {
    0: 'split out the target source',
    1: '1st Continuum image',
    2: 'Pcal1',
    3: 'Plotcal - pcal1',
    4: 'Applycal - pcal1',
    5: 'Image - pcal1',
    6: 'Pcal2',
    7: 'Plotcal - pcal2',
    8: 'Applycal - pcal2',
    9: 'Image - pcal2',
    10: 'Pcal3',
    11: 'Plotcal - pcal3',
    12: 'Applycal - pcal3',
    13: 'Image - pcal3',
    14: 'apcal - with pcal3 applied',
    15: 'Plotcal - apcal',
    16: 'Applycal - apcal AND pcal3',
    17: 'Split the selfcal applied data',
    18: 'Image - Final image - selfcal done and applied'}

try:
    print 'List of steps to be executed ...', mysteps
    thesteps = mysteps
except:
    print 'global variable mysteps not set.'
if (thesteps==[]):
    thesteps = range(0,len(step_title))
    print 'Executing all steps: ', thesteps
#
# split out just needs to be run at start or if you need to redo the full selfcal afresh
#
mystep = 0
if(mystep in thesteps):
  print 'Step ', mystep, step_title[mystep]
  os.system('rm -rf '+visname+'*')

  split(
    vis         = inputvisname, 
    outputvis   = visname, 
    field       = '3', 
    datacolumn  = 'data') # make sure you have the correct field

# From here the field is always = '0' as we only have the target source itself

# continuum

mystep = 1
if(mystep in thesteps):
  print 'Step ', mystep, step_title[mystep]

  # continuum image
  
  os.system('rm -rf '+souname+'.B4.cont.initial*')

  clean(vis=visname,
      spw = spwcont,
      imagename = souname+'.B4.cont.initial',
      field='0',
      cell=cell,
      imsize=imagesize,
      threshold='0.05mJy',
      mode='mfs',
      outframe='LSRK',
      niter=50000,  
      weighting='briggs',
      robust=0.5,
      interactive=True)



# pcal 1

mystep = 2
if(mystep in thesteps):
  print 'Step ', mystep, step_title[mystep]


  ## inf time is ~5 mins 
  ## find this roughly from listobs - time on source/target 
  os.system('rm -rf pcal1')
  gaincal(vis=visname,
       caltable='pcal1',
       gaintype='T',  
       refant='DA59',
       calmode='p',
       combine='spw',
       spw=spwcont,
       field='0',     
       solint='inf',  # ie. te full scan
       minsnr=3.0,
       minblperant=4)


# plot pcal1
mystep = 3
if(mystep in thesteps):
  print 'Step ', mystep, step_title[mystep]
  
  plotcal(caltable='pcal1',xaxis='time',yaxis='phase',   
       spw='',iteration='antenna',
        subplot=421,plotrange=[0,0,-180,180])


# apply pcal1
mystep = 4
if(mystep in thesteps):
  print 'Step ', mystep, step_title[mystep]


  applycal(vis=visname,
     spwmap=[0,0,0,0],  ## make sure you map includes the correct number of SPW - e.g here 0,0,0,0 maps to 0,1,2,3 - if you have 8 SPW spwmap = [0,0,0,0,0,0,0,0]
     spw='0,1,2,3',
     field='0', 
     gaintable=['pcal1'],
     gainfield='',  # will be the source itself
     calwt=F,
     flagbackup=T, 
     applymode='calonly')  # or set as 'calflag'



# clean with pcal 1 

mystep = 5 
if(mystep in thesteps):
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf '+souname+'.B4.cont_pcal1*')
  clean(vis=visname,    
      spw = spwcont,  
      imagename = souname+'.B4.cont_pcal1', 
      field='0',   
      cell=cell,   
      imsize=imagesize,   
      outframe='LSRK',   
      niter=10000,     
      interactive=True, 
      threshold='0.05mJy', 
      pbcor=False,    
      weighting='briggs', 
      robust=0.5,    
      mode = 'mfs')


# pcal2

mystep = 6 
if(mystep in thesteps):
  print 'Step ', mystep, step_title[mystep]

# now push to 30 sec intervals  
  os.system('rm -rf pcal2')
  gaincal(vis=visname,
        caltable='pcal2',
        gaintype='T',    
        refant='DA59',
        calmode='p',
        combine='spw',
        spw=spwcont,
        field='',    
        solint='30s',
        minsnr=3.0,
        minblperant=4)


# plot 

mystep = 7
if(mystep in thesteps):
  print 'Step ', mystep, step_title[mystep]
  
  plotcal(caltable='pcal2',
        xaxis='time',
        yaxis='phase',  
        spw='',iteration='antenna',
        subplot=421,plotrange=[0,0,-180,180])


# apply pcal 2

mystep = 8
if(mystep in thesteps):
  print 'Step ', mystep, step_title[mystep]

  applycal(vis=visname,
         spwmap=[0,0,0,0],
         spw='0,1,2,3',
         field='0', 
         gaintable=['pcal2'],
         gainfield='',
         calwt=F,
         flagbackup=T, 
         applymode='calonly')


# clean with pcal 2 

mystep = 9
if(mystep in thesteps):
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf '+souname+'.B4.cont_pcal2*')
  clean(vis=visname,   
      spw = spwcont, 
      imagename = souname+'.B4.cont_pcal2', 
      field='0',
      cell=cell,  
      imsize=imagesize, 
      outframe='LSRK', 
      niter=10000,     
      interactive=True, 
      threshold='0.05mJy',  
      pbcor=False,   
      weighting='briggs',
      robust=0.5,   
      mode = 'mfs')



# pcal 3 - 6sec  

mystep = 10
if(mystep in thesteps):
  print 'Step ', mystep, step_title[mystep]
 


  # now to int - 6 sec
  os.system('rm -rf pcal3')
  gaincal(vis=visname,
        caltable='pcal3',
        gaintype='T',    
        refant='DA59',
        calmode='p',
        combine='spw',
        spw=spwcont,
        field='0',   
        solint='int',
        minsnr=3.0,
        minblperant=4)

# plot pcal 3

mystep = 11
if(mystep in thesteps):
  print 'Step ', mystep, step_title[mystep]
  
  plotcal(caltable='pcal3',
        xaxis='time',
        yaxis='phase',   
        spw='',
        iteration='antenna',
        subplot=421,plotrange=[0,0,-180,180])



# apply pcal 3

mystep = 12
if(mystep in thesteps):
  print 'Step ', mystep, step_title[mystep]

  applycal(vis=visname,
         spwmap=[0,0,0,0],
         spw='0,1,2,3',
         field='0', 
         gaintable=['pcal3'],
         gainfield='',
         calwt=F,
         flagbackup=T, 
         applymode='calonly')


# clean with pcal 3

mystep = 13
if(mystep in thesteps):
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf '+souname+'.B4.cont_pcal3*')
  clean(vis=visname,   
      spw = spwcont, 
      imagename = souname+'.B4.cont_pcal3', 
      field='0',
      cell=cell,  
      imsize=imagesize, 
      outframe='LSRK', 
      niter=10000,     
      interactive=True, 
      threshold='0.05mJy',  
      pbcor=False,   
      weighting='briggs',
      robust=0.5,   
      mode = 'mfs')


# apcal with pcal 3 applied

mystep = 14
if(mystep in thesteps):
   print 'Step ', mystep, step_title[mystep]

   ## apcal here - applying the best phase cal
   os.system('rm -rf apcal')
   gaincal(vis=visname,caltable='apcal',
        gaintype='T', 
        refant='DA59',
        calmode='ap',
        combine='spw',
        spw=spwcont,
        field='0',
        solint='inf',  # inf for slow amp variations 
        minsnr=3.0,
        minblperant=4, 
        gaintable=['pcal3'], 
        spwmap=[0,0,0,0])  # make sure to map !!


# plot apcal

mystep = 15
if(mystep in thesteps):
   print 'Step ', mystep, step_title[mystep]
   

   plotcal(caltable='apcal',
        xaxis='time',
        yaxis='phase', 
        spw='',
        iteration='antenna',
        subplot=421,plotrange=[0,0,-180,180])



   plotcal(caltable='apcal',
        xaxis='time',
        yaxis='amp', 
        spw='',
        iteration='antenna',
        subplot=421)




# apply apcal and pcal3 - tjhis is the final apply 

mystep = 16
if(mystep in thesteps):
   print 'Step ', mystep, step_title[mystep]
   


   applycal(vis=visname,
         spwmap=[[0,0,0,0],[0,0,0,0]],  # map amp and phase solns
         spw='0,1,2,3',
         field='0',     
         gaintable=['pcal3','apcal'], # two tables 
         gainfield='', # this will apply both tables to itself 
         calwt=F,
         flagbackup=T,  
         applymode='calonly')




# now split out the final dataset
mystep = 17
if(mystep in thesteps):
   print 'Step ', mystep, step_title[mystep]

   os.system('rm -rf '+souname+'scfinal.ms*')

   split(vis=visname, outputvis=souname+'scfinal.ms')


# final clean image - continuum

mystep = 18
if(mystep in thesteps):
   print 'Step ', mystep, step_title[mystep]


   os.system('rm -rf '+souname+'.B4.cont_scfinal*')
   clean(vis=souname+'scfinal.ms',   
      spw = spwcont,    
      imagename = souname+'.B4.cont_scfinal',   
      field='0', 
      cell=cell,   
      imsize=imagesize, 
      outframe='LSRK',  
      niter=10000,    
      interactive=True,
      threshold='0.05mJy', 
      pbcor=False, 
      weighting='briggs',  
      robust=0.5,  
      mode = 'mfs')




# for lines you will need to redo now uv-continuum subtraction
# and then re-run the images
# this can be done in the imaging script but now putting
# in the self-calibrated ms file and the input
# NOTE - watch that field is set to = '0' always as the
# selfcalibrated data ONLY contains the source

