# ALMA Data Reduction Script

# Calibration

thesteps = []
step_title = {0: 'Import of the ASDM',
              1: 'Fix of SYSCAL table times',
              2: 'listobs',
              3: 'A priori flagging',
              4: 'Generation and time averaging of the WVR cal table',
              5: 'Generation of the Tsys cal table',
              6: 'Generation of the antenna position cal table',
              7: 'Application of the WVR, Tsys and antpos cal tables',
              8: 'Split out science SPWs and time average',
              9: 'Listobs, and save original flags',
              10: 'Initial flagging',
              11: 'Putting a model for the flux calibrator(s)',
              12: 'Save flags before bandpass cal',
              13: 'Bandpass calibration',
              14: 'Save flags before gain cal',
              15: 'Gain calibration',
              16: 'Save flags before applycal',
              17: 'Application of the bandpass and gain cal tables',
              18: 'Split out corrected column',
              19: 'Save flags after applycal'}

if 'applyonly' not in globals(): applyonly = False
try:
  print 'List of steps to be executed ...', mysteps
  thesteps = mysteps
except:
  print 'global variable mysteps not set.'
if (thesteps==[]):
  thesteps = range(0,len(step_title))
  print 'Executing all steps: ', thesteps

# The Python variable 'mysteps' will control which steps
# are executed when you start the script using
#   execfile('scriptForCalibration.py')
# e.g. setting
#   mysteps = [2,3,4]
# before starting the script will make the script execute
# only steps 2, 3, and 4
# Setting mysteps = [] will make it execute all steps.

import re

import os

import casadef

if applyonly != True: es = aU.stuffForScienceDataReduction() 


if re.search('^5.4.0', '.'.join([str(i) for i in cu.version().tolist()[:-1]])) == None:
 sys.exit('ERROR: PLEASE USE THE SAME VERSION OF CASA THAT YOU USED FOR GENERATING THE SCRIPT: 5.4.0')


# CALIBRATE_AMPLI: J1517-243
# CALIBRATE_ATMOSPHERE: IRAS16293-2422,J1517-243,J1700-2610
# CALIBRATE_BANDPASS: J1700-2610
# CALIBRATE_DIFFGAIN: 
# CALIBRATE_FLUX: J1517-243
# CALIBRATE_FOCUS: 
# CALIBRATE_PHASE: J1625-2527
# CALIBRATE_POINTING: J1700-2610
# OBSERVE_CHECK: 
# OBSERVE_TARGET: IRAS16293-2422

# Using reference antenna = DA59

# Import of the ASDM
mystep = 0
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  if os.path.exists('uid___A002_X867766_Xa7.ms') == False:
    importasdm('uid___A002_X867766_Xa7', asis='Antenna Station Receiver Source CalAtmosphere CalWVR CorrelatorMode SBSummary', bdfflags=True, lazy=False, process_caldevice=False)
    if not os.path.exists('uid___A002_X867766_Xa7.ms.flagversions'):
      print 'ERROR in importasdm. Output MS is probably not useful. Will stop here.'
      thesteps = []
  if applyonly != True: es.fixForCSV2555('uid___A002_X867766_Xa7.ms')

# Fix of SYSCAL table times
mystep = 1
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  from recipes.almahelpers import fixsyscaltimes
  fixsyscaltimes(vis = 'uid___A002_X867766_Xa7.ms')

print "# A priori calibration"

# listobs
mystep = 2
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf uid___A002_X867766_Xa7.ms.listobs')
  listobs(vis = 'uid___A002_X867766_Xa7.ms',
    listfile = 'uid___A002_X867766_Xa7.ms.listobs')
  
  

# A priori flagging
mystep = 3
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  flagdata(vis = 'uid___A002_X867766_Xa7.ms',
    mode = 'manual',
    spw = '1~24',
    autocorr = True,
    flagbackup = False)
  
  flagdata(vis = 'uid___A002_X867766_Xa7.ms',
    mode = 'manual',
    intent = '*POINTING*,*SIDEBAND_RATIO*,*ATMOSPHERE*',
    flagbackup = False)
  
  flagcmd(vis = 'uid___A002_X867766_Xa7.ms',
    inpmode = 'table',
    useapplied = True,
    action = 'plot',
    plotfile = 'uid___A002_X867766_Xa7.ms.flagcmd.png')
  
  flagcmd(vis = 'uid___A002_X867766_Xa7.ms',
    inpmode = 'table',
    useapplied = True,
    action = 'apply')
  

# Generation and time averaging of the WVR cal table
mystep = 4
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf uid___A002_X867766_Xa7.ms.wvr') 
  
  os.system('rm -rf uid___A002_X867766_Xa7.ms.wvrgcal') 
  
  mylogfile = casalog.logfile()
  casalog.setlogfile('uid___A002_X867766_Xa7.ms.wvrgcal')
  
  wvrgcal(vis = 'uid___A002_X867766_Xa7.ms',
    caltable = 'uid___A002_X867766_Xa7.ms.wvr',
    spw = [17, 19, 21, 23],
    smooth = '6.048s',
    toffset = 0,
    tie = ['IRAS16293-2422,J1625-2527'],
    statsource = 'IRAS16293-2422')
  
  casalog.setlogfile(mylogfile)
  
  if applyonly != True: aU.plotWVRSolutions(caltable='uid___A002_X867766_Xa7.ms.wvr', spw='17', antenna='DA59',
    yrange=[-199,199],subplot=22, interactive=False,
    figfile='uid___A002_X867766_Xa7.ms.wvr.plots/uid___A002_X867766_Xa7.ms.wvr') 
  
  #Note: If you see wraps in these plots, try changing yrange or unwrap=True 
  #Note: If all plots look strange, it may be a bad WVR on the reference antenna.
  #      To check, you can set antenna='' to show all baselines.
  

# Generation of the Tsys cal table
mystep = 5
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf uid___A002_X867766_Xa7.ms.tsys') 
  gencal(vis = 'uid___A002_X867766_Xa7.ms',
    caltable = 'uid___A002_X867766_Xa7.ms.tsys',
    caltype = 'tsys')
  
  # Flagging edge channels
  
  flagdata(vis = 'uid___A002_X867766_Xa7.ms.tsys',
    mode = 'manual',
    spw = '9:0~3;124~127,11:0~3;124~127,13:0~3;124~127,15:0~3;124~127',
    flagbackup = False)
  
  if applyonly != True: aU.plotbandpass(caltable='uid___A002_X867766_Xa7.ms.tsys', overlay='time', 
    xaxis='freq', yaxis='amp', subplot=22, buildpdf=False, interactive=False,
    showatm=True,pwv='auto',chanrange='92.1875%',showfdm=True, showBasebandNumber=True, showimage=False, 
    field='', figfile='uid___A002_X867766_Xa7.ms.tsys.plots.overlayTime/uid___A002_X867766_Xa7.ms.tsys') 
  
  
  if applyonly != True: es.checkCalTable('uid___A002_X867766_Xa7.ms.tsys', msName='uid___A002_X867766_Xa7.ms', interactive=False) 
  

# Generation of the antenna position cal table
mystep = 6
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  # Warning: no baseline run found for following antenna(s): ['DV21'].
  
  # Position for antenna DV19 is derived from baseline run made on 2014-07-20 05:52:41.
  
  # Position for antenna DA65 is derived from baseline run made on 2014-07-20 05:52:41.
  
  # Position for antenna DA64 is derived from baseline run made on 2014-07-20 05:52:41.
  
  # Position for antenna DA62 is derived from baseline run made on 2014-07-20 05:52:41.
  
  # Position for antenna DA61 is derived from baseline run made on 2014-07-20 05:52:41.
  
  # Position for antenna DA43 is derived from baseline run made on 2014-07-20 05:52:41.
  
  # Position for antenna PM04 is derived from baseline run made on 2014-07-20 05:52:41.
  
  # Position for antenna DV09 is derived from baseline run made on 2014-07-20 05:52:41.
  
  # Position for antenna DA55 is derived from baseline run made on 2014-07-20 05:52:41.
  
  # Position for antenna DV15 is derived from baseline run made on 2014-07-20 05:52:41.
  
  # Position for antenna DA59 is derived from baseline run made on 2014-07-20 05:52:41.
  
  os.system('rm -rf uid___A002_X867766_Xa7.ms.antpos') 
  gencal(vis = 'uid___A002_X867766_Xa7.ms',
    caltable = 'uid___A002_X867766_Xa7.ms.antpos',
    caltype = 'antpos',
    antenna = 'DA43,DA55,DA59,DA61,DA62,DA64,DA65,DV09,DV15,DV19,PM04',
  #  parameter = [0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
    parameter = [-2.48696e-04,5.34164e-04,-1.16226e-04,-8.72406e-05,-1.12338e-05,-4.28975e-04,-1.58530e-04,4.74761e-04,-1.08255e-04,-1.06799e-04,2.58474e-04,-1.73918e-04,-1.20528e-04,2.78828e-04,-1.97415e-04,-1.49859e-04,4.95780e-04,-7.97325e-05,-2.02210e-04,5.52506e-04,-1.81630e-04,4.62020e-05,5.13086e-04,1.09555e-04,2.28080e-04,-7.61057e-04,-3.25253e-04,-1.46414e-04,7.59410e-04,3.42971e-04,-2.01085e-04,3.88610e-04,-2.44074e-05])
  
  
  # antenna x_offset y_offset z_offset total_offset baseline_date
  # DV15     2.28080e-04   -7.61057e-04   -3.25253e-04    8.58498e-04      2014-07-20 05:52:41
  # DV19    -1.46414e-04    7.59410e-04    3.42971e-04    8.46031e-04      2014-07-20 05:52:41
  # DA65    -2.02210e-04    5.52506e-04   -1.81630e-04    6.15744e-04      2014-07-20 05:52:41
  # DA43    -2.48696e-04    5.34164e-04   -1.16226e-04    6.00574e-04      2014-07-20 05:52:41
  # DV09     4.62020e-05    5.13086e-04    1.09555e-04    5.26682e-04      2014-07-20 05:52:41
  # DA64    -1.49859e-04    4.95780e-04   -7.97325e-05    5.24035e-04      2014-07-20 05:52:41
  # DA59    -1.58530e-04    4.74761e-04   -1.08255e-04    5.12103e-04      2014-07-20 05:52:41
  # PM04    -2.01085e-04    3.88610e-04   -2.44074e-05    4.38234e-04      2014-07-20 05:52:41
  # DA55    -8.72406e-05   -1.12338e-05   -4.28975e-04    4.37901e-04      2014-07-20 05:52:41
  # DA62    -1.20528e-04    2.78828e-04   -1.97415e-04    3.62278e-04      2014-07-20 05:52:41
  # DA61    -1.06799e-04    2.58474e-04   -1.73918e-04    3.29336e-04      2014-07-20 05:52:41
  

# Application of the WVR, Tsys and antpos cal tables
mystep = 7
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  
  
  from recipes.almahelpers import tsysspwmap
  tsysmap = tsysspwmap(vis = 'uid___A002_X867766_Xa7.ms', tsystable = 'uid___A002_X867766_Xa7.ms.tsys', tsysChanTol = 1)
  
  
  
  applycal(vis = 'uid___A002_X867766_Xa7.ms',
    field = '0',
    spw = '17,19,21,23',
    gaintable = ['uid___A002_X867766_Xa7.ms.tsys', 'uid___A002_X867766_Xa7.ms.wvr', 'uid___A002_X867766_Xa7.ms.antpos'],
    gainfield = ['0', '', ''],
    interp = 'linear,linear',
    spwmap = [tsysmap,[],[]],
    calwt = True,
    flagbackup = False)
  
  
  
  applycal(vis = 'uid___A002_X867766_Xa7.ms',
    field = '1',
    spw = '17,19,21,23',
    gaintable = ['uid___A002_X867766_Xa7.ms.tsys', 'uid___A002_X867766_Xa7.ms.wvr', 'uid___A002_X867766_Xa7.ms.antpos'],
    gainfield = ['1', '', ''],
    interp = 'linear,linear',
    spwmap = [tsysmap,[],[]],
    calwt = True,
    flagbackup = False)
  
  
  
  # Note: J1625-2527 didn't have any Tsys measurement, so I used the one made on IRAS16293-2422. This is probably Ok.
  
  applycal(vis = 'uid___A002_X867766_Xa7.ms',
    field = '2',
    spw = '17,19,21,23',
    gaintable = ['uid___A002_X867766_Xa7.ms.tsys', 'uid___A002_X867766_Xa7.ms.wvr', 'uid___A002_X867766_Xa7.ms.antpos'],
    gainfield = ['3', '', ''],
    interp = 'linear,linear',
    spwmap = [tsysmap,[],[]],
    calwt = True,
    flagbackup = False)
  
  
  
  applycal(vis = 'uid___A002_X867766_Xa7.ms',
    field = '3',
    spw = '17,19,21,23',
    gaintable = ['uid___A002_X867766_Xa7.ms.tsys', 'uid___A002_X867766_Xa7.ms.wvr', 'uid___A002_X867766_Xa7.ms.antpos'],
    gainfield = ['3', '', ''],
    interp = 'linear,linear',
    spwmap = [tsysmap,[],[]],
    calwt = True,
    flagbackup = False)
  
  
  
  if applyonly != True: es.getCalWeightStats('uid___A002_X867766_Xa7.ms') 
  

# Split out science SPWs and time average
mystep = 8
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf uid___A002_X867766_Xa7.ms.split') 
  os.system('rm -rf uid___A002_X867766_Xa7.ms.split.flagversions') 
  
  split(vis = 'uid___A002_X867766_Xa7.ms',
    outputvis = 'uid___A002_X867766_Xa7.ms.split',
    datacolumn = 'corrected',
    spw = '17,19,21,23',
    keepflags = True)
  
  

print "# Calibration"

# Listobs, and save original flags
mystep = 9
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf uid___A002_X867766_Xa7.ms.split.listobs')
  listobs(vis = 'uid___A002_X867766_Xa7.ms.split',
    listfile = 'uid___A002_X867766_Xa7.ms.split.listobs')
  
  
  if not os.path.exists('uid___A002_X867766_Xa7.ms.split.flagversions/Original.flags'):
    flagmanager(vis = 'uid___A002_X867766_Xa7.ms.split',
      mode = 'save',
      versionname = 'Original')
  
  

# Initial flagging
mystep = 10
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  # Flagging shadowed data
  
  flagdata(vis = 'uid___A002_X867766_Xa7.ms.split',
    mode = 'shadow',
    flagbackup = False)
  
  

# Putting a model for the flux calibrator(s)
mystep = 11
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  setjy(vis = 'uid___A002_X867766_Xa7.ms.split',
    standard = 'manual',
    field = 'J1517-243',
    fluxdensity = [1.46812290882, 0, 0, 0],
    spix = -0.248770914736,
    reffreq = '152.113999195GHz')
  
  

# Save flags before bandpass cal
mystep = 12
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  
  flagmanager(vis = 'uid___A002_X867766_Xa7.ms.split',
    mode = 'save',
    versionname = 'BeforeBandpassCalibration')
  
  

# Bandpass calibration
mystep = 13
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf uid___A002_X867766_Xa7.ms.split.ap_pre_bandpass') 
  
  gaincal(vis = 'uid___A002_X867766_Xa7.ms.split',
    caltable = 'uid___A002_X867766_Xa7.ms.split.ap_pre_bandpass',
    field = '0', # J1700-2610
    spw = '0:0~3839,1:0~3839,2:0~3839,3:0~3839',
    scan = '1,2,4',
    solint = 'int',
    refant = 'DA59',
    calmode = 'p')
  
  if applyonly != True: es.checkCalTable('uid___A002_X867766_Xa7.ms.split.ap_pre_bandpass', msName='uid___A002_X867766_Xa7.ms.split', interactive=False) 
  
  os.system('rm -rf uid___A002_X867766_Xa7.ms.split.bandpass') 
  bandpass(vis = 'uid___A002_X867766_Xa7.ms.split',
    caltable = 'uid___A002_X867766_Xa7.ms.split.bandpass',
    field = '0', # J1700-2610
    scan = '1,2,4',
    solint = 'inf',
    combine = 'scan',
    refant = 'DA59',
    solnorm = True,
    bandtype = 'B',
    gaintable = 'uid___A002_X867766_Xa7.ms.split.ap_pre_bandpass')
  
  os.system('rm -rf uid___A002_X867766_Xa7.ms.split.bandpass_smooth20ch') 
  
  bandpass(vis = 'uid___A002_X867766_Xa7.ms.split',
    caltable = 'uid___A002_X867766_Xa7.ms.split.bandpass_smooth20ch',
    field = '0', # J1700-2610
    scan = '1,2,4',
    solint = 'inf,20ch',
    combine = 'scan',
    refant = 'DA59',
    solnorm = True,
    bandtype = 'B',
    gaintable = 'uid___A002_X867766_Xa7.ms.split.ap_pre_bandpass')
  
  if applyonly != True: es.checkCalTable('uid___A002_X867766_Xa7.ms.split.bandpass_smooth20ch', msName='uid___A002_X867766_Xa7.ms.split', interactive=False) 
  
  if applyonly != True: es.checkCalTable('uid___A002_X867766_Xa7.ms.split.bandpass', msName='uid___A002_X867766_Xa7.ms.split', interactive=False) 
  

# Save flags before gain cal
mystep = 14
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  
  flagmanager(vis = 'uid___A002_X867766_Xa7.ms.split',
    mode = 'save',
    versionname = 'BeforeGainCalibration')
  
  

# Gain calibration
mystep = 15
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf uid___A002_X867766_Xa7.ms.split.phase_int') 
  gaincal(vis = 'uid___A002_X867766_Xa7.ms.split',
    caltable = 'uid___A002_X867766_Xa7.ms.split.phase_int',
    field = '0~2', # J1700-2610,J1517-243,J1625-2527
    solint = 'int',
    refant = 'DA59',
    gaintype = 'G',
    calmode = 'p',
    gaintable = 'uid___A002_X867766_Xa7.ms.split.bandpass_smooth20ch')
  
  if applyonly != True: es.checkCalTable('uid___A002_X867766_Xa7.ms.split.phase_int', msName='uid___A002_X867766_Xa7.ms.split', interactive=False) 
  
  os.system('rm -rf uid___A002_X867766_Xa7.ms.split.ampli_inf') 
  gaincal(vis = 'uid___A002_X867766_Xa7.ms.split',
    caltable = 'uid___A002_X867766_Xa7.ms.split.ampli_inf',
    field = '0~2', # J1700-2610,J1517-243,J1625-2527
    solint = 'inf',
    refant = 'DA59',
    gaintype = 'T',
    calmode = 'a',
    gaintable = ['uid___A002_X867766_Xa7.ms.split.bandpass_smooth20ch', 'uid___A002_X867766_Xa7.ms.split.phase_int'])
  
  if applyonly != True: es.checkCalTable('uid___A002_X867766_Xa7.ms.split.ampli_inf', msName='uid___A002_X867766_Xa7.ms.split', interactive=False) 
  
  os.system('rm -rf uid___A002_X867766_Xa7.ms.split.flux_inf') 
  os.system('rm -rf uid___A002_X867766_Xa7.ms.split.fluxscale') 
  mylogfile = casalog.logfile()
  casalog.setlogfile('uid___A002_X867766_Xa7.ms.split.fluxscale')
  
  fluxscaleDict = fluxscale(vis = 'uid___A002_X867766_Xa7.ms.split',
    caltable = 'uid___A002_X867766_Xa7.ms.split.ampli_inf',
    fluxtable = 'uid___A002_X867766_Xa7.ms.split.flux_inf',
    reference = '1') # J1517-243
  
  casalog.setlogfile(mylogfile)
  
  if applyonly != True: es.fluxscale2(caltable = 'uid___A002_X867766_Xa7.ms.split.ampli_inf', removeOutliers=True, msName='uid___A002_X867766_Xa7.ms', writeToFile=True, preavg=10000)
  
  os.system('rm -rf uid___A002_X867766_Xa7.ms.split.phase_inf') 
  gaincal(vis = 'uid___A002_X867766_Xa7.ms.split',
    caltable = 'uid___A002_X867766_Xa7.ms.split.phase_inf',
    field = '0~2', # J1700-2610,J1517-243,J1625-2527
    solint = 'inf',
    refant = 'DA59',
    gaintype = 'G',
    calmode = 'p',
    gaintable = 'uid___A002_X867766_Xa7.ms.split.bandpass_smooth20ch')
  
  if applyonly != True: es.checkCalTable('uid___A002_X867766_Xa7.ms.split.phase_inf', msName='uid___A002_X867766_Xa7.ms.split', interactive=False) 
  

# Save flags before applycal
mystep = 16
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  
  flagmanager(vis = 'uid___A002_X867766_Xa7.ms.split',
    mode = 'save',
    versionname = 'BeforeApplycal')
  
  

# Application of the bandpass and gain cal tables
mystep = 17
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  for i in ['0', '1']: # J1700-2610,J1517-243
    applycal(vis = 'uid___A002_X867766_Xa7.ms.split',
      field = str(i),
      gaintable = ['uid___A002_X867766_Xa7.ms.split.bandpass_smooth20ch', 'uid___A002_X867766_Xa7.ms.split.phase_int', 'uid___A002_X867766_Xa7.ms.split.flux_inf'],
      gainfield = ['', i, i],
      interp = 'linear,linear',
      calwt = True,
      flagbackup = False)
  
  applycal(vis = 'uid___A002_X867766_Xa7.ms.split',
    field = '2,3', # IRAS16293-2422
    gaintable = ['uid___A002_X867766_Xa7.ms.split.bandpass_smooth20ch', 'uid___A002_X867766_Xa7.ms.split.phase_inf', 'uid___A002_X867766_Xa7.ms.split.flux_inf'],
    gainfield = ['', '2', '2'], # J1625-2527
    interp = 'linear,linear',
    calwt = True,
    flagbackup = False)
  

# Split out corrected column
mystep = 18
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf uid___A002_X867766_Xa7.ms.split.cal') 
  os.system('rm -rf uid___A002_X867766_Xa7.ms.split.cal.flagversions') 
  
  listOfIntents = ['CALIBRATE_AMPLI#ON_SOURCE',
   'CALIBRATE_BANDPASS#ON_SOURCE',
   'CALIBRATE_FLUX#ON_SOURCE',
   'CALIBRATE_PHASE#ON_SOURCE',
   'CALIBRATE_WVR#ON_SOURCE',
   'OBSERVE_TARGET#ON_SOURCE']
  
  split(vis = 'uid___A002_X867766_Xa7.ms.split',
    outputvis = 'uid___A002_X867766_Xa7.ms.split.cal',
    datacolumn = 'corrected',
    intent = ','.join(listOfIntents),
    keepflags = True)
  
  

# Save flags after applycal
mystep = 19
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  
  flagmanager(vis = 'uid___A002_X867766_Xa7.ms.split.cal',
    mode = 'save',
    versionname = 'AfterApplycal')
  
  

